@@ -9,6 +9,7 @@ from pullenti.ner.ProcessorService import ProcessorService
 from pullenti.ner.SourceOfAnalysis import SourceOfAnalysis
 from pullenti.ner.keyword.KeywordAnalyzer import KeywordAnalyzer
 from pullenti.ner.keyword.KeywordReferent import KeywordReferent
+from pullenti.ner.keyword.KeywordType import KeywordType
 from pymorphy2 import MorphAnalyzer
 import emoji
 
@@ -214,6 +215,6 @@ class NLProcessor:
         with ProcessorService.create_specific_processor(KeywordAnalyzer.ANALYZER_NAME) as proc:
             ar = proc.process(SourceOfAnalysis(text_without_emoji), None, None)
             for e0_ in ar.entities:
-                if isinstance(e0_, KeywordReferent):
+                if isinstance(e0_, KeywordReferent) and e0_.typ != KeywordType.ANNOTATION:
                     keywords.append(e0_.to_string(short_variant=True))
         return keywords
